@@ -1,5 +1,6 @@
 import os
 import json  # better to use "imports ujson as json" for the best performance
+from urllib.request import pathname2url # for converting "+","*", etc. in file paths to appropriate urls
 import uuid
 import logging
 from PIL import Image
@@ -12,22 +13,21 @@ logger = logging.getLogger('root')
 
 def convert_yolo_to_ls(input_dir, out_file,
                        to_name='image', from_name='label', out_type="annotations",
-                       image_root_url='/data/local-files/?d=', image_ext='.jpg'):
+                       image_root_url='/data/local-files/?d=', image_ext='.jpg,.jpeg,.png'):
 
     """ Convert YOLO labeling to Label Studio JSON
-
     :param input_dir: directory with YOLO where images, labels, notes.json are located
     :param out_file: output file with Label Studio JSON tasks
     :param to_name: object name from Label Studio labeling config
     :param from_name: control tag name from Label Studio labeling config
     :param out_type: annotation type - "annotations" or "predictions"
     :param image_root_url: root URL path where images will be hosted, e.g.: http://example.com/images
-    :param image_ext: image extension to search: .jpg, .png
+    :param image_ext: image extension/s - single string or comma separated list to search, eg. .jpeg or .jpg, .png and so on.
     """
 
     tasks = []
     logger.info('Reading YOLO notes and categories from %s', input_dir)
-
+        
     # build categories=>labels dict
     notes_file = os.path.join(input_dir, 'classes.txt')
     with open(notes_file) as f:
@@ -39,65 +39,75 @@ def convert_yolo_to_ls(input_dir, out_file,
     label_config_file = out_file.replace('.json', '') + '.label_config.xml'
     generate_label_config(categories, {from_name: 'RectangleLabels'}, to_name, from_name, label_config_file)
 
-    # labels, one label per image
+    # define directories
     labels_dir = os.path.join(input_dir, 'labels')
+    images_dir = os.path.join(input_dir, 'images')
     logger.info('Converting labels from %s', labels_dir)
+    
+    # build array out of provided comma separated image_extns (str -> array)
+    image_ext = [x.strip() for x in image_ext.split(",")]
+    logger.info(f'image extensions->, {image_ext}')
 
-    for f in os.listdir(labels_dir):
-        image_file_base = f[0:-4] + image_ext
-        image_file = os.path.join(input_dir, 'images', image_file_base)
-        label_file = os.path.join(labels_dir, f)
-
-        if not f.endswith('.txt'):
+    # loop through images
+    for f in os.listdir(images_dir):
+        image_file_found_flag = False
+        for ext in image_ext:
+            if f.endswith(ext):
+                image_file = f
+                image_file_base = f[0:-len(ext)]
+                image_file_found_flag = True
+                break
+        if not image_file_found_flag:
             continue
-
-        if not os.path.exists(image_file):
-            logger.info("Can't convert YOLO to Label Studio JSON without image source: %s", image_file)
-            continue
-
+        
         task = {
             "data": {
-                "image": os.path.join(image_root_url, image_file_base)
-            },
-            # 'annotations' or 'predictions'
-            out_type: [
+                # eg. '../../foo+you.py' -> '../../foo%2Byou.py'
+                "image": pathname2url(os.path.join(image_root_url, image_file))
+            }
+        }
+
+        # define coresponding label file and check existence
+        label_file = os.path.join(labels_dir, image_file_base + '.txt')
+
+        if os.path.exists(label_file):
+            task[out_type] = [
                 {
                     "result": [],
                     "ground_truth": False,
                 }
             ]
-        }
 
-        # read image sizes
-        im = Image.open(image_file)
-        image_width, image_height = im.size
+            # read image sizes
+            with Image.open(os.path.join(images_dir, image_file)) as im:
+                image_width, image_height = im.size
 
-        with open(label_file) as file:
-            # convert all bounding boxes to Label Studio Results
-            lines = file.readlines()
-            for line in lines:
-                label_id, x, y, width, height = line.split()
-                x, y, width, height = float(x), float(y), float(width), float(height)
-                item = {
-                    "id": uuid.uuid4().hex[0:10],
-                    "type": "rectanglelabels",
-                    "value": {
-                        "x": (x-width/2) * 100,
-                        "y": (y-height/2) * 100,
-                        "width": width * 100,
-                        "height": height * 100,
-                        "rotation": 0,
-                        "rectanglelabels": [
-                            categories[int(label_id)]
-                        ]
-                    },
-                    "to_name": to_name,
-                    "from_name": from_name,
-                    "image_rotation": 0,
-                    "original_width": image_width,
-                    "original_height": image_height
-                }
-                task[out_type][0]['result'].append(item)
+            with open(label_file) as file:
+                # convert all bounding boxes to Label Studio Results
+                lines = file.readlines()
+                for line in lines:
+                    label_id, x, y, width, height = line.split()
+                    x, y, width, height = float(x), float(y), float(width), float(height)
+                    item = {
+                        "id": uuid.uuid4().hex[0:10],
+                        "type": "rectanglelabels",
+                        "value": {
+                            "x": (x-width/2) * 100,
+                            "y": (y-height/2) * 100,
+                            "width": width * 100,
+                            "height": height * 100,
+                            "rotation": 0,
+                            "rectanglelabels": [
+                                categories[int(label_id)]
+                            ]
+                        },
+                        "to_name": to_name,
+                        "from_name": from_name,
+                        "image_rotation": 0,
+                        "original_width": image_width,
+                        "original_height": image_height
+                    }
+                    task[out_type][0]['result'].append(item)
 
         tasks.append(task)
 
@@ -152,6 +162,6 @@ def add_parser(subparsers):
     )
     yolo.add_argument(
         '--image-ext', dest='image_ext',
-        help='image extension to search: .jpg, .png',
+        help='image extension to search: .jpeg or .jpg, .png',
         default='.jpg',
-    )
+    )
\ No newline at end of file
